<style type="text/css">
textarea#sql_code, .codemirror {
	width: 98%;
	height: 200px;
	margin: auto;
	text-align: left;
}
</style>
